# Padalec Library

A small python library with some useful tools.

## Table of Contents

- [Installation](#installation)
- [License](#license)
- [Contact](#contact)

## Installation

1. [Prerequisites](#prerequisites)
2. [Installation Steps](#installation-steps)

### Prerequisites

- Python 3.12.0

### Installation Steps

```bash
pip install padaleclib
```

### License

This project is licensed under the [MIT License](https://opensource.org/licenses/MIT). See [LICENSE.md](LICENSE.md) for details.

### Contact

For any questions, issues or feedback, feel free to create an issue on [GitHub](https://github.com/DarkKryU/Padalec-Lib/issues/new).
